@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.71'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.72'; # VERSION
 
 use 5.010;
 use strict;
@@ -134,7 +134,7 @@ $SPEC{cmdline_src_stdin_or_args_array} = {
 };
 sub cmdline_src_stdin_or_args_array {
     my %args = @_;
-    [200, "OK", "a1=[".join(",",@{ $args{a1} })."]", {'func.args'=>\%args}];
+    [200, "OK", "a1=[".join(",",@{ $args{a1} // [] })."]", {'func.args'=>\%args}];
 }
 
 $SPEC{cmdline_src_multi_stdin} = {
@@ -225,7 +225,7 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.71 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-02-26.
+This document describes version 0.72 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2016-05-20.
 
 =head1 FUNCTIONS
 
@@ -234,7 +234,7 @@ This document describes version 0.71 of Perinci::Examples::CmdLineSrc (from Perl
 
 This function has args with cmdline_src=file.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -262,7 +262,7 @@ Return value:  (any)
 
 This function has non-str/non-array arg with cmdline_src.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -288,7 +288,7 @@ Return value:  (any)
 
 This function has multiple args with cmdline_src stdin/stdin_or_files.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -318,7 +318,7 @@ This function has several stdin_line arguments.
 
 And one also has its is_password property set to true.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -348,7 +348,7 @@ Return value:  (any)
 
 This function has arg with cmdline_src=stdin.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -374,7 +374,7 @@ Return value:  (any)
 
 This function has a single stdin_line argument.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -402,7 +402,7 @@ Return value:  (any)
 
 This function has array arg with cmdline_src=stdin_or_args.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -428,7 +428,7 @@ Return value:  (any)
 
 This function has array arg with cmdline_src=stdin_or_file.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -454,7 +454,7 @@ Return value:  (any)
 
 This function has str arg with cmdline_src=stdin_or_file.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -480,7 +480,7 @@ Return value:  (any)
 
 This function has array arg with cmdline_src=stdin_or_files.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -506,7 +506,7 @@ Return value:  (any)
 
 This function has str arg with cmdline_src=stdin_or_files.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -532,7 +532,7 @@ Return value:  (any)
 
 This function has arg with cmdline_src=stdin.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -558,7 +558,7 @@ Return value:  (any)
 
 This function has arg with unknown cmdline_src value.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -587,7 +587,7 @@ Accept binary in stdin/file.
 This function is like the one in C<Perinci::Examples> but argument is accepted
 via C<stdin_or_files>.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
