@@ -1,7 +1,7 @@
 package Perinci::Examples::Coercion;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.71'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.72'; # VERSION
 
 use 5.010;
 use strict;
@@ -14,10 +14,11 @@ $SPEC{coerce_to_epoch} = {
     summary => "Accept a date (e.g. '2015-11-20', etc), return its Unix epoch",
     args => {
         date => {
-            schema => 'date*',
+            schema => ['date*', {
+                'x.perl.coerce_to' => 'float(epoch)',
+            }],
             req => 1,
             pos => 0,
-            'x.perl.coerce_to' => 'int(epoch)',
         },
     },
 };
@@ -31,10 +32,11 @@ $SPEC{coerce_to_secs} = {
     summary => "Accept a duration (e.g. '2hour', 'P2D'), return number of seconds",
     args => {
         duration => {
-            schema => 'duration*',
+            schema => ['duration*', {
+                'x.perl.coerce_to' => 'float(secs)',
+            }],
             req => 1,
             pos => 0,
-            'x.perl.coerce_to' => 'int(secs)',
         },
     },
 };
@@ -58,7 +60,7 @@ Perinci::Examples::Coercion - Coercion examples
 
 =head1 VERSION
 
-This document describes version 0.71 of Perinci::Examples::Coercion (from Perl distribution Perinci-Examples), released on 2016-02-26.
+This document describes version 0.72 of Perinci::Examples::Coercion (from Perl distribution Perinci-Examples), released on 2016-05-20.
 
 =head1 DESCRIPTION
 
@@ -69,7 +71,7 @@ This document describes version 0.71 of Perinci::Examples::Coercion (from Perl d
 
 Accept a date (e.g. '2015-11-20', etc), return its Unix epoch.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -95,7 +97,7 @@ Return value:  (any)
 
 Accept a duration (e.g. '2hour', 'P2D'), return number of seconds.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
