@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.71'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.72'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.71 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-02-26.
+This document describes version 0.72 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-05-20.
 
 =head1 DESCRIPTION
 
@@ -104,15 +104,15 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_naked( arg1 => "abc", arg2 => 10); # -> ["arg2", 10, "arg1", "abc"]
+ result_naked(arg1 => "abc", arg2 => 10); # -> ["arg2", 10, "arg1", "abc"]
 
 =item * With the optional arg3:
 
- result_naked( arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg3", 0.5, "arg2", 20]
+ result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg2", 20, "arg1", "def"]
 
 =back
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -139,19 +139,19 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_not_naked( arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
+ result_not_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
 
 =item * With the optional arg3:
 
- result_not_naked( arg1 => "def", arg2 => 20, arg3 => 0.5);
+ result_not_naked(arg1 => "def", arg2 => 20, arg3 => 0.5);
 
 Result:
 
- [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
+ [200, "OK", ["arg1", "def", "arg2", 20, "arg3", 0.5], {}]
 
 =back
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
